@@ -4,10 +4,11 @@ use strict;
 use warnings;
 use Alien::Build::Plugin;
 use Module::Load ();
+use Alien::Build::Util qw( _has_ssl );
 use Carp ();
 
 # ABSTRACT: Download negotiation plugin
-our $VERSION = '1.57_01'; # TRIAL VERSION
+our $VERSION = '1.58_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -37,19 +38,27 @@ has 'prefer' => 1;
 sub pick
 {
   my($self) = @_;
-  
+
   $self->scheme(
     $self->url !~ m!(ftps?|https?|file):!i
       ? 'file'
       : $self->url =~ m!^([a-z]+):!i
   ) unless defined $self->scheme;
-  
+
   if($self->scheme eq 'https' || ($self->scheme eq 'http' && $self->ssl))
   {
-    if($self->bootstrap_ssl && ! eval { require Net::SSLeay; 1 })
+    if($self->bootstrap_ssl && ! _has_ssl)
     {
       return (['Fetch::CurlCommand','Fetch::Wget'], 'Decode::HTML');
     }
+    elsif(_has_ssl)
+    {
+      return ('Fetch::HTTPTiny', 'Decode::HTML');
+    }
+    elsif(do { require Alien::Build::Plugin::Fetch::CurlCommand; Alien::Build::Plugin::Fetch::CurlCommand->protocol_ok('https') })
+    {
+      return ('Fetch::CurlCommand', 'Decode::HTML');
+    }
     else
     {
       return ('Fetch::HTTPTiny', 'Decode::HTML');
@@ -85,7 +94,7 @@ sub pick
 sub init
 {
   my($self, $meta) = @_;
-  
+
   unless(defined $self->url)
   {
     if(defined $meta->prop->{start_url})
@@ -97,14 +106,14 @@ sub init
       Carp::croak "url is a required property unless you use the start_url directive";
     }
   }
-  
+
   $meta->add_requires('share' => 'Alien::Build::Plugin::Download::Negotiate' => '0.61')
     if $self->passive;
 
   $meta->prop->{plugin_download_negotiate_default_url} = $self->url;
 
   my($fetch, @decoders) = $self->pick;
-  
+
   $fetch = [ $fetch ] unless ref $fetch;
 
   foreach my $fetch (@$fetch)
@@ -113,16 +122,17 @@ sub init
     push @args, ssl => $self->ssl;
     # For historical reasons, we pass the URL into older fetch plugins, because
     # this used to be the interface.  Using start_url is now preferred!
-    push @args, url => $self->url if $fetch =~ /^Fetch::(HTTPTiny|LWP|Local|LocalDir|NetFTP)$/;
+    push @args, url => $self->url if $fetch =~ /^Fetch::(HTTPTiny|LWP|Local|LocalDir|NetFTP|CurlCommand)$/;
     push @args, passive => $self->passive if $fetch eq 'Fetch::NetFTP';
-  
+    push @args, bootstrap_ssl => $self->bootstrap_ssl if $self->bootstrap_ssl;
+
     $meta->apply_plugin($fetch, @args);
   }
-  
+
   if($self->version)
   {
     $meta->apply_plugin($_) for @decoders;
-    
+
     if(defined $self->prefer && ref($self->prefer) eq 'CODE')
     {
       $meta->add_requires('share' => 'Alien::Build::Plugin::Download::Negotiate' => '1.30');
@@ -132,7 +142,7 @@ sub init
     }
     elsif($self->prefer)
     {
-      $meta->apply_plugin('Prefer::SortVersions', 
+      $meta->apply_plugin('Prefer::SortVersions',
         (defined $self->filter ? (filter => $self->filter) : ()),
         version => $self->version,
       );
@@ -158,7 +168,7 @@ Alien::Build::Plugin::Download::Negotiate - Download negotiation plugin
 
 =head1 VERSION
 
-version 1.57_01
+version 1.58_01
 
 =head1 SYNOPSIS
 
