@@ -10,7 +10,7 @@ use File::Temp qw( tempdir );
 use Capture::Tiny qw( capture_merged );
 
 # ABSTRACT: Plugin to extract an archive using command line tools
-our $VERSION = '1.57_01'; # TRIAL VERSION
+our $VERSION = '1.58_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -23,7 +23,7 @@ sub gzip_cmd
 }
 
 
-sub _which { File::Which::which(@_) }
+sub _which { scalar File::Which::which(@_) }
 
 sub bzip2_cmd
 {
@@ -316,7 +316,7 @@ Alien::Build::Plugin::Extract::CommandLine - Plugin to extract an archive using
 
 =head1 VERSION
 
-version 1.57_01
+version 1.58_01
 
 =head1 SYNOPSIS
 
