@@ -4,10 +4,11 @@ use strict;
 use warnings;
 use Alien::Build::Plugin;
 use File::Basename ();
+use Alien::Build::Util qw( _ssl_reqs );
 use Carp ();
 
 # ABSTRACT: Plugin for fetching files using HTTP::Tiny
-our $VERSION = '1.57_01'; # TRIAL VERSION
+our $VERSION = '1.58_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -16,6 +17,9 @@ has '+url' => '';
 
 has ssl => 0;
 
+# ignored for compatability
+has bootstrap_ssl => 1;
+
 sub init
 {
   my($self, $meta) = @_;
@@ -29,10 +33,13 @@ sub init
 
   if($self->url =~ /^https:/ || $self->ssl)
   {
-    $meta->add_requires('share' => 'IO::Socket::SSL' => '1.56' );
-    $meta->add_requires('share' => 'Net::SSLeay'     => '1.49' );
+    my $reqs = _ssl_reqs;
+    foreach my $mod (sort keys %$reqs)
+    {
+      $meta->add_requires('share' => $mod => $reqs->{$mod});
+    }
   }
-  
+
   $meta->register_hook( fetch => sub {
     my($build, $url) = @_;
     $url ||= $self->url;
@@ -44,12 +51,12 @@ sub init
     {
       my $status = $res->{status} || '---';
       my $reason = $res->{reason} || 'unknown';
-      
+
       $build->log("$status $reason fetching $url");
       if($status == 599)
       {
         $build->log("exception: $_") for split /\n/, $res->{content};
-        
+
         my($can_ssl, $why_ssl) = HTTP::Tiny->can_ssl;
         if(! $can_ssl)
         {
@@ -65,7 +72,7 @@ sub init
           }
         }
       }
-      
+
       die "error fetching $url: $status $reason";
     }
 
@@ -84,7 +91,7 @@ sub init
         $filename = $1;
       }
     }
-    
+
     if($type eq 'text/html')
     {
       return {
@@ -101,7 +108,7 @@ sub init
         content  => $res->{content},
       };
     }
-    
+
   });
 
   $self;
@@ -121,7 +128,7 @@ Alien::Build::Plugin::Fetch::HTTPTiny - Plugin for fetching files using HTTP::Ti
 
 =head1 VERSION
 
-version 1.57_01
+version 1.58_01
 
 =head1 SYNOPSIS
 
