@@ -10,18 +10,24 @@ use Capture::Tiny qw( capture );
 use File::chdir;
 
 # ABSTRACT: Plugin for fetching files using wget
-our $VERSION = '1.57_01'; # TRIAL VERSION
+our $VERSION = '1.58_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
 has wget_command => sub { defined $ENV{WGET} ? which($ENV{WGET}) : which('wget') };
 has ssl => 0;
 
+# when bootstrapping we have to specify this plugin as a prereq
+# 1 is the default so that when this plugin is used directly
+# you also get the prereq
+has bootstrap_ssl => 1;
+
 sub init
 {
   my($self, $meta) = @_;
-  
-  $meta->add_requires('configure', 'Alien::Build::Plugin::Fetch::Wget' => '1.19');
+
+  $meta->add_requires('configure', 'Alien::Build::Plugin::Fetch::Wget' => '1.19')
+    if $self->bootstrap_ssl;
 
   $meta->register_hook(
     fetch => sub {
@@ -29,11 +35,11 @@ sub init
       $url ||= $meta->prop->{start_url};
 
       my($scheme) = $url =~ /^([a-z0-9]+):/i;
-      
+
       if($scheme eq 'http' || $scheme eq 'https')
       {
         local $CWD = tempdir( CLEANUP => 1 );
-        
+
         my($stdout, $stderr) = $self->_execute(
           $build,
           $self->wget_command,
@@ -101,7 +107,7 @@ Alien::Build::Plugin::Fetch::Wget - Plugin for fetching files using wget
 
 =head1 VERSION
 
-version 1.57_01
+version 1.58_01
 
 =head1 SYNOPSIS
 
