@@ -7,11 +7,11 @@ use Path::Tiny qw( path );
 use Config;
 
 # ABSTRACT: Private utility functions for Alien::Build
-our $VERSION = '1.57_01'; # TRIAL VERSION
+our $VERSION = '1.58_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
-our @EXPORT_OK = qw( _mirror _dump _destdir_prefix _perl_config );
+our @EXPORT_OK = qw( _mirror _dump _destdir_prefix _perl_config _ssl_reqs _has_ssl );
 
 # usage: _mirror $source_directory, $dest_direction, \%options
 #
@@ -29,7 +29,7 @@ sub _mirror
   require Alien::Build;
   require File::Find;
   require File::Copy;
-  
+
   File::Find::find({
     wanted => sub {
       next unless -e $File::Find::name;
@@ -85,7 +85,7 @@ sub _mirror
     },
     no_chdir => 1,
   }, "$src_root");
-  
+
   ();
 }
 
@@ -115,6 +115,26 @@ sub _perl_config
   $Config{$key};
 }
 
+sub _ssl_reqs
+{
+  return {
+    'Net::SSLeay' => '1.49',
+    'IO::Socket::SSL' => '1.56',
+  };
+}
+
+sub _has_ssl
+{
+  my %reqs = %{ _ssl_reqs() };
+  eval {
+    require Net::SSLeay;
+    die "need Net::SSLeay $reqs{'Net::SSLeay'}" unless Net::SSLeay->VERSION($reqs{'Net::SSLeay'});
+    require IO::Socket::SSL;
+    die "need IO::Socket::SSL $reqs{'IO::Socket::SSL'}" unless IO::Socket::SSL->VERSION($reqs{'IO::Socket::SSL'});
+  };
+  $@ eq '';
+}
+
 1;
 
 __END__
@@ -129,7 +149,7 @@ Alien::Build::Util - Private utility functions for Alien::Build
 
 =head1 VERSION
 
-version 1.57_01
+version 1.58_01
 
 =head1 DESCRIPTION
 
